/* Copyright (C) 2009, 2010, 2011 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */

#ifndef NDEBUG
int		Debug;

const char	Start_func_msg[] = "%s() started at %s\n";
const char	End_func_msg_int[] = "End %s() returning %d at %s\n";
const char	End_func_msg_pointer[] = "End %s() returning %p at %s\n";
const char	End_func_msg_void[] = "End %s() returning void at %s\n";
#else
const char	Start_func_msg[] = "";
const char	End_func_msg_int[] = "";
const char	End_func_msg_pointer[] = "";
const char	End_func_msg_void[] = "";
#endif
